//--------------------------------------------------------------
// File     : main.c
// Datum    : 12.11.2013
// Version  : 1.0
// Autor    : UB
// EMail    : mc-4u(@)t-online.de
// Web      : www.mikrocontroller-4u.de
// CPU      : STM32F429
// IDE      : CooCox CoIDE 1.7.4
// GCC      : 4.7 2012q4
// Module   : CMSIS_BOOT, M4_CMSIS_CORE
// Funktion : Demo der USB-HID-Host Library
// Hinweis  : Diese zwei Files muessen auf 8MHz stehen
//              "cmsis_boot/stm32f4xx.h"
//              "cmsis_boot/system_stm32f4xx.c"
// In Configuration diese Define hinzufgen :
// "STM32F429_439xx" , "__ASSEMBLY__" , "USE_STDPERIPH_DRIVER"
//--------------------------------------------------------------

#include "main.h"
#include "stm32_ub_led.h"
#include "stm32_ub_usb_hid_host.h"


//--------------------------------------------------------------
void mouse_function(void)
{
  // Maus-Daten abfragen
  UB_USB_HID_HOST_GetMouse();
  // Grne LED mit linker Maustaste ein/ausschalten
  if(USB_MOUSE_DATA.btn_left==MOUSE_BTN_PRESSED) {
    UB_Led_On(LED_GREEN); // grne LED einschalten
  }
  else {
    UB_Led_Off(LED_GREEN); // grne LED ausschalten
  }
}


//--------------------------------------------------------------
void key_function(void)
{
  uint8_t akt_key=0;

  // Keyboard-Daten abfragen
  akt_key=UB_USB_HID_HOST_GetKey();
  // Grne LED mit Tasten "1" und "2" ein/auschalten
  if(akt_key=='1') {
    UB_Led_On(LED_GREEN); // grne LED einschalten
  }
  if(akt_key=='2') {
    UB_Led_Off(LED_GREEN); // grne LED ausschalten
  }
}

//--------------------------------------------------------------
int main(void)
{
  USB_HID_HOST_STATUS_t host_status;

  SystemInit(); // Quarz Einstellungen aktivieren

  // Init der LEDs
  UB_Led_Init();

  // Init vom USB-OTG-Port als HID-HOST
  // (zum betreiben von USB-Mouse oder USB-Tastatur)
  UB_USB_HID_HOST_Init();

  while(1)
  {
    // pollen vom USB-Status
    host_status=UB_USB_HID_HOST_Do();
    if(host_status==USB_HID_MOUSE_CONNECTED) {
      // wenn USB-Maus gefunden wurde
      mouse_function();
    }
    else if(host_status==USB_HID_KEYBOARD_CONNECTED) {
      // wenn USB-Keyboard gefunden wurde
      key_function();
    }
    else if(host_status==USB_HID_DEV_NOT_SUPPORTED) {
      // wenn Fehler beim USB-Device
      UB_Led_On(LED_RED);
    }
    else {
      // wenn kein USB-Device vorhanden
      UB_Led_Off(LED_GREEN);
    }
  }
}

